<?php
/**
 * Plugin Name: myglobalHOST Add Expire Headers
 * Plugin URI:  https://www.myglobalhost.in/
 * Description: Automatically adds Expires headers to static assets for better browser caching and improved performance.
 * Version:     1.0.0
 * Author:      myglobalHOST
 * Author URI:  https://www.myglobalhost.net/
 * License:     GPL2
 */

// Function to add Expires headers
function add_expires_headers() {
    // Get the file extension from the requested URL
    $extension = pathinfo( $_SERVER['REQUEST_URI'], PATHINFO_EXTENSION );

    // Define cacheable file extensions and their corresponding max-age values (in seconds)
    $cacheable_extensions = array(
        'jpg'  => 31536000, // 1 year
        'jpeg' => 31536000, // 1 year
        'png'  => 31536000, // 1 year
        'gif'  => 31536000, // 1 year
        'webp' => 31536000, // 1 year
        'css'  => 604800,    // 1 week
        'js'   => 604800,    // 1 week
    );

    // Check if the requested file has a cacheable extension
    if ( array_key_exists( $extension, $cacheable_extensions ) ) {
        $max_age = $cacheable_extensions[ $extension ];

        // Set Expires header
        header( "Expires: " . gmdate( "D, d M Y H:i:s", time() + $max_age ) . " GMT" );

        // Also set Cache-Control header for compatibility
        header( "Cache-Control: public, max-age=$max_age" );
    }
}

add_action( 'send_headers', 'add_expires_headers' );
